@@ -358,10 +358,17 @@ class TPOTBase(BaseEstimator):
             elif callable(scoring):
                 # Heuristic to ensure user has not passed a metric
                 module = getattr(scoring, '__module__', None)
-                if hasattr(module, 'startswith') and \
+                if sys.version_info[0] < 3:
+                    if inspect.isfunction(scoring):
+                        args_list = inspect.getargspec(scoring)[0]
+                    else:
+                        args_list = inspect.getargspec(scoring.__call__)[0]
+                else:
+                    args_list = inspect.getfullargspec(scoring)[0]
+                if args_list == ["y_true", "y_pred"] or (hasattr(module, 'startswith') and \
                     (module.startswith('sklearn.metrics.') or module.startswith('tpot.metrics')) and \
                     not module.startswith('sklearn.metrics.scorer') and \
-                    not module.startswith('sklearn.metrics.tests.'):
+                    not module.startswith('sklearn.metrics.tests.')):
                     scoring_name = scoring.__name__
                     greater_is_better = 'loss' not in scoring_name and 'error' not in scoring_name
                     SCORERS[scoring_name] = make_scorer(scoring, greater_is_better=greater_is_better)
@@ -481,8 +488,10 @@ class TPOTBase(BaseEstimator):
                 self._pset.addTerminal(val, _type, name=terminal_name)
 
     def _setup_toolbox(self):
-        creator.create('FitnessMulti', base.Fitness, weights=(-1.0, 1.0))
-        creator.create('Individual', gp.PrimitiveTree, fitness=creator.FitnessMulti, statistics=dict)
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
+            creator.create('FitnessMulti', base.Fitness, weights=(-1.0, 1.0))
+            creator.create('Individual', gp.PrimitiveTree, fitness=creator.FitnessMulti, statistics=dict)
 
         self._toolbox = base.Toolbox()
         self._toolbox.register('expr', self._gen_grow_safe, pset=self._pset, min_=1, max_=3)
@@ -851,7 +860,7 @@ class TPOTBase(BaseEstimator):
             testing_features.astype(np.float64),
             testing_target.astype(np.float64)
         )
-        return abs(score)
+        return score
 
     def predict_proba(self, features):
         """Use the optimized pipeline to estimate the class probabilities for a feature set.
@@ -946,7 +955,7 @@ class TPOTBase(BaseEstimator):
             if e.errno == errno.EEXIST and os.path.isdir(self.periodic_checkpoint_folder):
                 pass # Folder already exists. User probably created it.
             else:
-                raise ValueError('Failed creating the periodic_checkpoint_folder:\n{}'.format(e))     
+                raise ValueError('Failed creating the periodic_checkpoint_folder:\n{}'.format(e))
 
     def export(self, output_file_name, skip_if_repeated=False):
         """Export the optimized pipeline as Python code.
